@@ -4,7 +4,7 @@ use 5.010001;
 use strict;
 use warnings;
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 1;
 #ABSTRACT: Utilities for serialization tasks
@@ -13,12 +13,16 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
 App::SerializeUtils - Utilities for serialization tasks
 
+=head1 VERSION
+
+This document describes version 0.07 of App::SerializeUtils (from Perl distribution App-SerializeUtils), released on 2014-05-22.
+
 =head1 SYNOPSIS
 
  $ script-that-produces-json | json2yaml
@@ -32,19 +36,39 @@ and output to stdout):
 
  dd2json
  dd2phpser
+ dd2sereal
+ dd2storable
  dd2yaml
 
  json2dd
  json2phpser
+ json2sereal
+ json2storable
  json2yaml
 
  phpser2dd
  phpser2json
+ phpser2sereal
+ phpser2storable
  phpser2yaml
 
+ sereal2dd
+ sereal2json
+ sereal2phpser
+ sereal2storable
+ sereal2yaml
+
+ storable2dd
+ storable2json
+ storable2phpser
+ storable2sereal
+ storable2yaml
+
  yaml2dd
  yaml2json
  yaml2phpser
+ yaml2sereal
+ yaml2storable
 
 Also included is this utility to pretty-print JSON:
 
@@ -64,6 +88,10 @@ L<JSON>
 
 L<PHP::Serialization>
 
+L<Sereal>
+
+L<Storable>
+
 L<YAML>
 
 =head1 HOMEPAGE
@@ -76,8 +104,7 @@ Source repository is at L<https://github.com/sharyanto/perl-App-SerializeUtils>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/Public/Dist/Display.html?Name=App-SerializeUtils
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-SerializeUtils>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -89,7 +116,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
